[Vtigercrm-commits] [vtiger-commits] r7491 - in /customerportal/trunk: include.php nusoap/lib/nusoap.php

vtigercrm-commits at vtiger.fosslabs.com vtigercrm-commits at vtiger.fosslabs.com
Sat Jun 24 16:41:09 EDT 2006


Author: mmbrich
Date: Sat Jun 24 14:41:08 2006
New Revision: 7491

Log:
fixes for soapclient already declared in php5

Modified:
    customerportal/trunk/include.php
    customerportal/trunk/nusoap/lib/nusoap.php

Modified: customerportal/trunk/include.php
==============================================================================
--- customerportal/trunk/include.php (original)
+++ customerportal/trunk/include.php Sat Jun 24 14:41:08 2006
@@ -15,7 +15,7 @@
 global $Server_Path;
 global $client;
 
-$client = new soapclient($Server_Path."/vtigerservice.php?service=customerportal", false, $proxy_host, $proxy_port, $proxy_username, $proxy_password);
+$client = new soapclient2($Server_Path."/vtigerservice.php?service=customerportal", false, $proxy_host, $proxy_port, $proxy_username, $proxy_password);
 
 
 ?>

Modified: customerportal/trunk/nusoap/lib/nusoap.php
==============================================================================
--- customerportal/trunk/nusoap/lib/nusoap.php (original)
+++ customerportal/trunk/nusoap/lib/nusoap.php Sat Jun 24 14:41:08 2006
@@ -4952,24 +4952,24 @@
 
 /**
 *
 * soapclient higher level class for easy usage.
 *
 * usage:
 *
 * // instantiate client with server info
-* $soapclient = new soapclient( string path [ ,boolean wsdl] );
+* $soapclient2 = new soapclient2( string path [ ,boolean wsdl] );
 *
 * // call method, get results
-* echo $soapclient->call( string methodname [ ,array parameters] );
+* echo $soapclient2->call( string methodname [ ,array parameters] );
 *
 * // bye bye client
-* unset($soapclient);
+* unset($soapclient2);
 *
 * @author   Dietrich Ayala <dietrich at ganx4.com>
 * @version  $Id: nusoap.php,v 1.1 2005/04/29 05:09:16 sarajkumar Exp $
 * @access   public
 */
-class soapclient extends nusoap_base  {
+class soapclient2 extends nusoap_base  {
 
 	var $username = '';
 	var $password = '';
@@ -5021,7 +5021,7 @@
 	* @param	integer $response_timeout set the response timeout
 	* @access   public
 	*/
-	function soapclient($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
+	function soapclient2($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
 		$this->endpoint = $endpoint;
 		$this->proxyhost = $proxyhost;
 		$this->proxyport = $proxyport;
@@ -5506,7 +5506,7 @@
 			}
 		}
 		$r = rand();
-		$evalStr = 'class soap_proxy_'.$r.' extends soapclient {
+		$evalStr = 'class soap_proxy_'.$r.' extends soapclient2 {
 				'.$evalStr.'
 			}';
 		//print "proxy class:<pre>$evalStr</pre>";
@@ -4952,24 +4952,24 @@
 /**
 *
-* soapclient higher level class for easy usage.
+* soapclient2 higher level class for easy usage.
 *
 * usage:





More information about the vtigercrm-commits mailing list